import { AwsCredentialIdentity } from "@smithy/types";
import { ProcessCredentials } from "./ProcessCredentials";
export declare const getValidatedProcessCredentials: (
  profileName: string,
  data: ProcessCredentials
) => AwsCredentialIdentity;
